% clear bac_wt_doubling_time;
% clear no_of_divisions_wt;
% clear bac_numbers_wt;
% Import the .mat files correponding to the datasets for growth rates of the WT and ESX-1
% deficient strains (labelled as pe35 in the file and the code below) in
% macrophages

rng('shuffle');
%no of repeats of the simulations
number_of_repeats=1000;
%simulate a typical MTB animal experiment
number_of_animals=5;
%starting innoculum for a typical animal experiment
infection_dose=50;
%timepoint in hours at which the bacterial numbers are ennumerated
timepoint=312; % day 7 over day 1;
%number of samples to choose for comparison of bacterial numbers 
sample_number=200;

%perform a Kernel Fit to the data 
wt_ns_pd=fitdist(wt_ns_mac, 'Kernel', 'Kernel','epanechnikov', 'Width',0.003);
wt_ds_pd=fitdist(wt_ds_mac, 'Kernel', 'Kernel','epanechnikov', 'Width',0.003);

pe35_ns_pd=fitdist(pe35_ns_mac, 'Kernel', 'Kernel','epanechnikov', 'Width',0.003);
pe35_ds_pd=fitdist(pe35_ds_mac, 'Kernel', 'Kernel','epanechnikov', 'Width',0.003);

%initialise the parameters for the simulation
bac_wt_growth_rate_ns=ones(number_of_repeats, infection_dose);
bac_wt_growth_rate_ds=ones(number_of_repeats, infection_dose);
bac_pe35_growth_rate_ns=ones(number_of_repeats, infection_dose);
bac_pe35_growth_rate_ds=ones(number_of_repeats, infection_dose);

no_of_divisions_wt_ns=ones(number_of_repeats, infection_dose);
no_of_divisions_wt_ds=ones(number_of_repeats, infection_dose);
no_of_divisions_pe35_ns=ones(number_of_repeats, infection_dose);
no_of_divisions_pe35_ds=ones(number_of_repeats, infection_dose);

bac_numbers_wt_ns=ones(number_of_repeats, infection_dose);
bac_numbers_wt_ds=ones(number_of_repeats, infection_dose);
bac_numbers_pe35_ns=ones(number_of_repeats, infection_dose);
bac_numbers_pe35_ds=ones(number_of_repeats, infection_dose);

%choose a number of bacteria corresponding to the innoculum size and assign
%each bacterium a growth rate chosen at random from the population
%distribution fot WT bacteria
for j = 1:number_of_repeats
    wt_ns_sample=wt_ns_pd.random([infection_dose,1]);
    wt_ds_sample=wt_ds_pd.random([infection_dose,1]);
    for i=1:infection_dose
        bac_wt_growth_rate_ns (j,i) = wt_ns_sample(i,1);
        bac_wt_growth_rate_ds (j,i) = wt_ds_sample(i,1);
    end
    
    for i=1:infection_dose
        no_of_divisions_wt_ns(j,i)=floor(timepoint.*bac_wt_growth_rate_ns(j,i));
        no_of_divisions_wt_ds(j,i)=floor(timepoint.*bac_wt_growth_rate_ds(j,i));
        if no_of_divisions_wt_ns(j,i)<0
            bac_numbers_wt_ns(j,i)=1;
        else
            bac_numbers_wt_ns(j,i)=2^(no_of_divisions_wt_ns(j,i));
        end
        if no_of_divisions_wt_ds(j,i)<0
            bac_numbers_wt_ds(j,i)=1;
        else
            bac_numbers_wt_ds(j,i)=2^(no_of_divisions_wt_ds(j,i));
        end
    end
    
    %choose a number of bacteria corresponding to the innoculum size and assign
    %each bacterium a growth rate chosen at random from the population
    %distribution fot WT bacteria
    
    for i=1:infection_dose
        bac_pe35_growth_rate_ns (j,i) = random(pe35_ns_pd);
        bac_pe35_growth_rate_ds (j,i) = random(pe35_ds_pd);
    end
    
    for i=1:infection_dose
        no_of_divisions_pe35_ns(j,i)=floor(timepoint.*bac_pe35_growth_rate_ns(j,i));
        no_of_divisions_pe35_ds(j,i)=floor(timepoint.*bac_pe35_growth_rate_ds(j,i));
        if no_of_divisions_pe35_ns(j,i)<0
            bac_numbers_pe35_ns(j,i)=1;
        else
            bac_numbers_pe35_ns(j,i)=2^(no_of_divisions_pe35_ns(j,i));
        end
        if no_of_divisions_pe35_ds(j,i)<0
            bac_numbers_pe35_ds(j,i)=1;
        else
            bac_numbers_pe35_ds(j,i)=2^(no_of_divisions_pe35_ds(j,i));
        end
    end
end

%ennumerate the bacteria in each population at the timepoint of interest
%for each repeat of the simulation

bac_sum_wt_ns = sum(bac_numbers_wt_ns,2);
bac_sum_pe35_ns = sum(bac_numbers_pe35_ns,2);

bac_sum_wt_ds = sum(bac_numbers_wt_ds,2);
bac_sum_pe35_ds = sum(bac_numbers_pe35_ds,2);

%sample a proportion of these simulations for calculating the ratio between
%the ESX-1 deficient strain and WT
for i=1:sample_number
   pe35_wt_ratio_ns(i,1)=median((datasample(bac_sum_pe35_ns,number_of_animals, 'Replace', false)))./median((datasample(bac_sum_wt_high, number_of_animals, 'Replace', false)));
   pe35_wt_ratio_ds(i,1)=median((datasample(bac_sum_pe35_ds,number_of_animals, 'Replace', false)))./median((datasample(bac_sum_wt_ds, number_of_animals, 'Replace', false)));
end 

